@@ -1,4 +1,4 @@
-from metacity.models.tiles.model import MetaTile
+from metacity.models.tiles.object import MetaTile
 from metacity.grid.config import RegularGridConfig
 from metacity.grid.slicer import RegularGridSlicer
 from metacity.grid.cache import RegularGridCache
